@@ -46,23 +46,8 @@ extern struct fsck_agg_record *agg_recptr;
 extern UniChar uni_message_parm[];
 extern UniChar *uni_msgprm;
 
-extern char message_parm_0[];
-extern char message_parm_1[];
-extern char message_parm_2[];
-extern char message_parm_3[];
-extern char message_parm_4[];
-extern char message_parm_5[];
-extern char message_parm_6[];
-extern char message_parm_7[];
-extern char message_parm_8[];
-extern char message_parm_9[];
-
-extern char *msgprms[];
-extern int16_t msgprmidx[];
-
 extern char *verbose_msg_ptr;
 
-extern char *MsgText[];
 extern char *Vol_Label;
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
@@ -561,54 +546,36 @@ int display_path(uint32_t inoidx, int inopfx, uint32_t ino_parent,
 	if ((!ino_recptr->unxpctd_prnts)
 	    || (!(ino_recptr->inode_type == directory_inode))) {
 		/* not directory w/ mult parents */
-		msgprms[0] = message_parm_0;
 		if (ino_recptr->inode_type == directory_inode) {
-			msgprmidx[0] = fsck_directory;
+			fsck_send_msg(fsck_INOPATHOK, fsck_ref_msg(fsck_directory),
+				      fsck_ref_msg(inopfx), inoidx, inopath);
 		} else if (ino_recptr->inode_type == char_special_inode) {
-			msgprmidx[0] = fsck_char_special;
+			fsck_send_msg(fsck_INOPATHOK, fsck_ref_msg(fsck_char_special),
+				      fsck_ref_msg(inopfx), inoidx, inopath);
 		} else if (ino_recptr->inode_type == block_special_inode) {
-			msgprmidx[0] = fsck_block_special;
+			fsck_send_msg(fsck_INOPATHOK, fsck_ref_msg(fsck_block_special),
+				      fsck_ref_msg(inopfx), inoidx, inopath);
 		} else if (ino_recptr->inode_type == FIFO_inode) {
-			msgprmidx[0] = fsck_FIFO;
+			fsck_send_msg(fsck_INOPATHOK, fsck_ref_msg(fsck_FIFO),
+				      fsck_ref_msg(inopfx), inoidx, inopath);
 		} else if (ino_recptr->inode_type == SOCK_inode) {
-			msgprmidx[0] = fsck_SOCK;
+			fsck_send_msg(fsck_INOPATHOK, fsck_ref_msg(fsck_SOCK),
+				      fsck_ref_msg(inopfx), inoidx, inopath);
 		} else {
 			/* regular file */
-			msgprmidx[0] = fsck_file;
+			fsck_send_msg(fsck_INOPATHOK, fsck_ref_msg(fsck_file),
+				      fsck_ref_msg(inopfx), inoidx, inopath);
 		}
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = inopfx;
-		sprintf(message_parm_2, "%d", inoidx);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		msgprms[3] = inopath;
-		msgprmidx[3] = 0;
-		fsck_send_msg(fsck_INOPATHOK, 4);
-
 	} else {
 		/* else a directory w/ multiple parents */
 		if (ino_parent == ino_recptr->parent_inonum) {
 			/* expected parent */
-			msgprms[0] = inopath;
-			msgprmidx[0] = 0;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = inopfx;
-			sprintf(message_parm_2, "%d", inoidx);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			fsck_send_msg(fsck_INOPATHCRCT, 3);
+			fsck_send_msg(fsck_INOPATHCRCT, inopath,
+				      fsck_ref_msg(inopfx), inoidx);
 		} else {
 			/* this is an illegal hard link */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = fsck_directory;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = inopfx;
-			sprintf(message_parm_2, "%d", inoidx);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			msgprms[3] = inopath;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_INOPATHBAD, 4);
+			fsck_send_msg(fsck_INOPATHBAD, fsck_ref_msg(fsck_directory),
+				      fsck_ref_msg(inopfx), inoidx, inopath);
 		}
 	}
 
@@ -702,20 +669,12 @@ int display_paths(uint32_t inoidx, struct fsck_inode_record *ino_recptr,
 					     this_path_ptr_ptr, ino_recptr);
 				if (intermed_rc != FSCK_OK) {
 					/* unable to obtain 1st path */
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = msg_info_ptr->msg_inopfx;
-					sprintf(message_parm_1, "%d",
-						this_parent);
-					msgprms[1] = message_parm_1;
-					msgprmidx[1] = 0;
-					msgprms[2] = message_parm_2;
-					msgprmidx[2] = msg_info_ptr->msg_inotyp;
-					msgprms[3] = msgprms[0];
-					msgprmidx[3] = msgprmidx[0];
-					sprintf(message_parm_4, "%d", inoidx);
-					msgprms[4] = message_parm_4;
-					msgprmidx[4] = 0;
-					fsck_send_msg(fsck_INOCNTGETPATH, 5);
+					fsck_send_msg(fsck_INOCNTGETPATH,
+						      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+						      this_parent,
+						      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+						      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+						      inoidx);
 					if (intermed_rc < 0) {
 						/* it's fatal */
 						dips_rc = intermed_rc;
@@ -785,24 +744,13 @@ int display_paths(uint32_t inoidx, struct fsck_inode_record *ino_recptr,
 								 ino_recptr);
 					} else {
 						/* unable to obtain next path */
-						msgprms[0] = message_parm_0;
-						msgprmidx[0] =
-						    msg_info_ptr->msg_inopfx;
-						sprintf(message_parm_1, "%d",
-							this_parent);
-						msgprms[1] = message_parm_1;
-						msgprmidx[1] = 0;
-						msgprms[2] = message_parm_2;
-						msgprmidx[2] =
-						    msg_info_ptr->msg_inotyp;
-						msgprms[3] = msgprms[0];
-						msgprmidx[3] = msgprmidx[0];
-						sprintf(message_parm_4, "%d",
-							inoidx);
-						msgprms[4] = message_parm_4;
-						msgprmidx[4] = 0;
 						fsck_send_msg
-						    (fsck_INOCNTGETPATH, 5);
+						    (fsck_INOCNTGETPATH,
+						     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+						     this_parent,
+						     fsck_ref_msg(msg_info_ptr->msg_inotyp),
+						     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+						     inoidx);
 						if (intermed_rc < 0) {
 							dips_rc = intermed_rc;
 						}
@@ -820,14 +768,8 @@ int display_paths(uint32_t inoidx, struct fsck_inode_record *ino_recptr,
 	 */
       out:
 	if ((dips_rc == FSCK_OK) && (!a_path_displayed)) {
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = msg_info_ptr->msg_inotyp;
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = msg_info_ptr->msg_inopfx;
-		sprintf(message_parm_2, "%d", inoidx);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		fsck_send_msg(fsck_INOCANTNAME, 3);
+		fsck_send_msg(fsck_INOCANTNAME, fsck_ref_msg(msg_info_ptr->msg_inotyp),
+			      fsck_ref_msg(msg_info_ptr->msg_inopfx), inoidx);
 	}
 
 	return (dips_rc);
@@ -1118,18 +1060,11 @@ int in_inode_data_check(struct fsck_inode_record *inorecptr,
 			inorecptr->inline_data_err = 1;
 			inorecptr->clr_ea_fld = 1;
 			agg_recptr->corrections_needed = 1;
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			sprintf(message_parm_3, "%d",
-				fsck_longdata_and_otherinline);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_INOINLINECONFLICT, 4);
+			fsck_send_msg(fsck_INOINLINECONFLICT,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      fsck_longdata_and_otherinline);
 		}
 		if (agg_recptr->this_inode.acl_inline) {
 			/* conflict */
@@ -1137,18 +1072,11 @@ int in_inode_data_check(struct fsck_inode_record *inorecptr,
 			inorecptr->inline_data_err = 1;
 			inorecptr->clr_acl_fld = 1;
 			agg_recptr->corrections_needed = 1;
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			sprintf(message_parm_3, "%d",
-				fsck_longdata_and_otherinline);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_INOINLINECONFLICT, 4);
+			fsck_send_msg(fsck_INOINLINECONFLICT,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      fsck_longdata_and_otherinline);
 		}
 	} else {
 		if (agg_recptr->this_inode.ea_inline
@@ -1157,18 +1085,11 @@ int in_inode_data_check(struct fsck_inode_record *inorecptr,
 			inorecptr->clr_ea_fld = 1;
 			inorecptr->clr_acl_fld = 1;
 			agg_recptr->corrections_needed = 1;
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			sprintf(message_parm_3, "%d",
-				fsck_longdata_and_otherinline);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_INOINLINECONFLICT, 4);
+			fsck_send_msg(fsck_INOINLINECONFLICT,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      fsck_longdata_and_otherinline);
 		}
 	}
 
@@ -1488,16 +1409,11 @@ int validate_ACL(struct dinode *inoptr, uint32_t inoidx,
 	    && (dxd_ptr->flag != DXD_CORRUPT)) {
 		/* not a single extent AND not inline AND not already
 		 * reported */
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = msg_info_ptr->msg_inotyp;
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = msg_info_ptr->msg_inopfx;
-		sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		msgprms[3] = message_parm_3;
-		msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-		fsck_send_msg(fsck_BADINODXDFLDD, 4);
+		fsck_send_msg(fsck_BADINODXDFLDD,
+			      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+			      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+			      msg_info_ptr->msg_inonum,
+			      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 		inorecptr->clr_acl_fld = 1;
 		inorecptr->ignore_acl_blks = 1;
 		agg_recptr->corrections_needed = 1;
@@ -1521,16 +1437,11 @@ int validate_ACL(struct dinode *inoptr, uint32_t inoidx,
 			 * the length extends
 			 * beyond the end of the inode
 			 */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-			fsck_send_msg(fsck_BADINODXDFLDL, 4);
+			fsck_send_msg(fsck_BADINODXDFLDL,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 
 			inorecptr->clr_acl_fld = 1;
 			agg_recptr->corrections_needed = 1;
@@ -1543,16 +1454,11 @@ int validate_ACL(struct dinode *inoptr, uint32_t inoidx,
 		if ((ext_length == 0) || (dxd_ptr->size < shortest_valid)
 		    || (dxd_ptr->size > longest_valid)) {
 			/* invalid length */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-			fsck_send_msg(fsck_BADINODXDFLDL, 4);
+			fsck_send_msg(fsck_BADINODXDFLDL,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 
 			inorecptr->clr_acl_fld = 1;
 			inorecptr->ignore_acl_blks = 1;
@@ -1801,16 +1707,11 @@ int validate_data(struct dinode *inoptr, uint32_t inoidx,
 			inorecptr->ignore_alloc_blks = 1;
 			agg_recptr->corrections_needed = 1;
 		}
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = msg_info_ptr->msg_inotyp;
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = msg_info_ptr->msg_inopfx;
-		sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		msgprms[3] = message_parm_3;
-		msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-		fsck_send_msg(fsck_BADINODXDFLDD, 4);
+		fsck_send_msg(fsck_BADINODXDFLDD,
+			      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+			      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+			      msg_info_ptr->msg_inonum,
+			      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 	}
       out:
 	return (vd_rc);
@@ -1844,7 +1745,6 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 	int intermed_rc = FSCK_OK;
 	int dtree_rc = FSCK_OK;
 	dxd_t *dxd_ptr;
-	xtpage_t *xtp_ptr;
 	int8_t xTree_ignore_alloc_blks = 0;
 
 	dxd_ptr = &(inoptr->di_dxd);
@@ -1870,16 +1770,11 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 		inorecptr->ignore_alloc_blks = 1;
 		agg_recptr->corrections_needed = 1;
 
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = msg_info_ptr->msg_inotyp;
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = msg_info_ptr->msg_inopfx;
-		sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		msgprms[3] = message_parm_3;
-		msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-		fsck_send_msg(fsck_BADINODXDFLDD, 4);
+		fsck_send_msg(fsck_BADINODXDFLDD,
+			      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+			      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+			      msg_info_ptr->msg_inonum,
+			      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 
 		goto out;
 	}
@@ -1900,11 +1795,6 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 	 */
 	if (((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
 	    && inoptr->di_next_index > MAX_INLINE_DIRTABLE_ENTRY + 1) {
-		/*
-		 * figure out how much space the root occupies in the inode
-		 * itself
-		 */
-		xtp_ptr = (xtpage_t *) (&inoptr->di_dirtable);
 		/*
 		 * validate the tree contents and record the extents it
 		 * describes until and unless the tree is found to be corrupt
@@ -2102,16 +1992,11 @@ int validate_EA(struct dinode *inoptr, uint32_t inoidx,
 	/* there is an EA for this inode */
 	if ((dxd_ptr->flag != DXD_EXTENT) && (dxd_ptr->flag != DXD_INLINE)) {
 		/* not a single extent AND not inline */
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = msg_info_ptr->msg_inotyp;
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = msg_info_ptr->msg_inopfx;
-		sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		msgprms[3] = message_parm_3;
-		msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-		fsck_send_msg(fsck_BADINODXDFLDD, 4);
+		fsck_send_msg(fsck_BADINODXDFLDD,
+			      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+			      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+			      msg_info_ptr->msg_inonum,
+			      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 		inorecptr->clr_ea_fld = 1;
 		inorecptr->ignore_ea_blks = 1;
 		agg_recptr->corrections_needed = 1;
@@ -2134,16 +2019,11 @@ int validate_EA(struct dinode *inoptr, uint32_t inoidx,
 			 * the length extends
 			 * beyond the end of the inode
 			 */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-			fsck_send_msg(fsck_BADINODXDFLDL, 4);
+			fsck_send_msg(fsck_BADINODXDFLDL,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 
 			inorecptr->clr_ea_fld = 1;
 			agg_recptr->corrections_needed = 1;
@@ -2167,16 +2047,11 @@ int validate_EA(struct dinode *inoptr, uint32_t inoidx,
 		if ((ext_length == 0) || (dxd_ptr->size < shortest_valid)
 		    || (dxd_ptr->size > longest_valid)) {
 			/* invalid length */
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-			fsck_send_msg(fsck_BADINODXDFLDL, 4);
+			fsck_send_msg(fsck_BADINODXDFLDL,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 
 			extent_is_valid = 0;
 			inorecptr->ignore_ea_blks = 1;
@@ -2219,16 +2094,11 @@ int validate_EA(struct dinode *inoptr, uint32_t inoidx,
 			   &(agg_recptr->ea_buf_data_len),
 			   &(agg_recptr->ea_agg_offset));
 		if (intermed_rc != FSCK_OK) {
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = msg_info_ptr->msg_dxdtyp;
-			fsck_send_msg(fsck_BADINODXDFLDO, 4);
+			fsck_send_msg(fsck_BADINODXDFLDO,
+				      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+				      msg_info_ptr->msg_inonum,
+				      fsck_ref_msg(msg_info_ptr->msg_dxdtyp));
 
 			inorecptr->clr_ea_fld = 1;
 			agg_recptr->corrections_needed = 1;
@@ -2247,14 +2117,10 @@ int validate_EA(struct dinode *inoptr, uint32_t inoidx,
       out:
 	if (ea_format_bad) {
 		/* bad ea but haven't notified anyone */
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = msg_info_ptr->msg_inotyp;
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = msg_info_ptr->msg_inopfx;
-		sprintf(message_parm_2, "%d", msg_info_ptr->msg_inonum);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		fsck_send_msg(fsck_EAFORMATBAD, 3);
+		fsck_send_msg(fsck_EAFORMATBAD,
+			      fsck_ref_msg(msg_info_ptr->msg_inotyp),
+			      fsck_ref_msg(msg_info_ptr->msg_inopfx),
+			      msg_info_ptr->msg_inonum);
 		inorecptr->clr_ea_fld = 1;
 		agg_recptr->corrections_needed = 1;
 		vea_rc = FSCK_OK;
@@ -2322,12 +2188,9 @@ int validate_record_fileset_inode(uint32_t inonum, uint32_t inoidx,
 		 * itself)
 		 */
 		agg_recptr->corrections_needed = 1;
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = ino_msg_info_ptr->msg_inopfx;
-		sprintf(message_parm_1, "%d", ino_msg_info_ptr->msg_inonum);
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = 0;
-		fsck_send_msg(fsck_BADINOTYP, 2);
+		fsck_send_msg(fsck_BADINOTYP,
+			      fsck_ref_msg(ino_msg_info_ptr->msg_inopfx),
+			      ino_msg_info_ptr->msg_inonum);
 
 		goto out;
 	}
@@ -2421,18 +2284,11 @@ int validate_record_fileset_inode(uint32_t inonum, uint32_t inoidx,
 			     agg_recptr->this_inode.all_blks);
 #endif
 
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = ino_msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = ino_msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d",
-				ino_msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			sprintf(message_parm_3, "%d", 9);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_BADKEYS, 4);
+			fsck_send_msg(fsck_BADKEYS,
+				      fsck_ref_msg(ino_msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(ino_msg_info_ptr->msg_inopfx),
+				      ino_msg_info_ptr->msg_inonum,
+				      9);
 
 			inorecptr->selected_to_rls = 1;
 			inorecptr->ignore_alloc_blks = 1;
@@ -2477,18 +2333,11 @@ int validate_record_fileset_inode(uint32_t inonum, uint32_t inoidx,
 				     inonum, min_size, max_size,
 				     inoptr->di_size);
 #endif
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = ino_msg_info_ptr->msg_inotyp;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = ino_msg_info_ptr->msg_inopfx;
-				sprintf(message_parm_2, "%d",
-					ino_msg_info_ptr->msg_inonum);
-				msgprms[2] = message_parm_2;
-				msgprmidx[2] = 0;
-				sprintf(message_parm_3, "%d", 10);
-				msgprms[3] = message_parm_3;
-				msgprmidx[3] = 0;
-				fsck_send_msg(fsck_BADKEYS, 4);
+				fsck_send_msg(fsck_BADKEYS,
+					      fsck_ref_msg(ino_msg_info_ptr->msg_inotyp),
+					      fsck_ref_msg(ino_msg_info_ptr->msg_inopfx),
+					      ino_msg_info_ptr->msg_inonum,
+					      10);
 
 				inorecptr->selected_to_rls = 1;
 				inorecptr->ignore_alloc_blks = 1;
@@ -2501,18 +2350,11 @@ int validate_record_fileset_inode(uint32_t inonum, uint32_t inoidx,
 		/* the tree looks ok */
 		intermed_rc = in_inode_data_check(inorecptr, ino_msg_info_ptr);
 		if (inorecptr->selected_to_rls) {
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = ino_msg_info_ptr->msg_inotyp;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = ino_msg_info_ptr->msg_inopfx;
-			sprintf(message_parm_2, "%d",
-				ino_msg_info_ptr->msg_inonum);
-			msgprms[2] = message_parm_2;
-			msgprmidx[2] = 0;
-			sprintf(message_parm_3, "%d", 39);
-			msgprms[3] = message_parm_3;
-			msgprmidx[3] = 0;
-			fsck_send_msg(fsck_BADKEYS, 4);
+			fsck_send_msg(fsck_BADKEYS,
+				      fsck_ref_msg(ino_msg_info_ptr->msg_inotyp),
+				      fsck_ref_msg(ino_msg_info_ptr->msg_inopfx),
+				      ino_msg_info_ptr->msg_inonum,
+				      39);
 
 			goto out;
 		}
